# Akashi Commnad Line Tool

Unofficial [akashi](https://ak4.jp/) command line tool. 

This command line tool can record your attendance from command lime.

# Requirements

- Python 3.5 or higher
- [chromedriver](http://chromedriver.chromium.org)

# Install

```shell
$ pip install akashi
```

# Usage

```
$ akashi --help
Usage: akashi [OPTIONS] COMMAND [ARGS]...

Options:
  --help  Show this message and exit.

Commands:
  attend  Attend to akashi
  leave   Leave to akashi
  login   Login to akashi
  logout  Logout to akashi
```

# License

MIT License.
